# Prologue

_Enter FOO_

**FOO**  
Bar.

**A Bar**  
Bar!

**Bar's Foo**  
Foo!

_Exeunt_

# ACT I

### Prologue

_Enter BAR_

**BAR**  
_[Aside]_  
Foo.

# INTERMISSION

### SCENE I.

_Enter FOO and BAR_

**FOO**  
_[To BAR]_  
Bar.

**BAR**  
Foo.


**FOO**  
Bar. ...

**BAR**  
... Foo. ...

**FOO**  
... Bar.

_A long stage direction that goes on forever and says far to much to be
reasonable. So much so that it takes up more than two lines, which is
just ridiculous. I mean seriously, why? Why write so much for one stage
direction? For what purpose?_

# EPILOGUE

_Enter FOO_

**FOO**  
_[Reads]_  
Foo.
